pub enum BatchResult {
Success(Value),
Error(BatchError),
}Expand description
Result of a single request within a batch
Variants
Implementations
Sourceimpl BatchResult
impl BatchResult
Sourcepub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Check if the result is successful
Sourcepub fn success_value(&self) -> Option<&Value>
pub fn success_value(&self) -> Option<&Value>
Get the success value if this result is successful
Sourcepub fn error_value(&self) -> Option<&BatchError>
pub fn error_value(&self) -> Option<&BatchError>
Get the error if this result is an error