pub struct BatchError {
pub request_index: usize,
pub error_code: String,
pub error_message: String,
pub recoverable: bool,
}Expand description
Error information for a failed request in a batch
Fields
request_index: usizeIndex of the failed request in the original batch
error_code: StringError code categorizing the failure
error_message: StringHuman-readable error message
recoverable: boolWhether this error is recoverable through retry
Implementations
Sourceimpl BatchError
impl BatchError
Sourcepub fn new(
request_index: usize,
error_code: String,
error_message: String,
recoverable: bool,
) -> Self
pub fn new( request_index: usize, error_code: String, error_message: String, recoverable: bool, ) -> Self
Create a new batch error
Sourcepub fn recoverable(
request_index: usize,
error_code: String,
error_message: String,
) -> Self
pub fn recoverable( request_index: usize, error_code: String, error_message: String, ) -> Self
Create a recoverable error
Sourcepub fn non_recoverable(
request_index: usize,
error_code: String,
error_message: String,
) -> Self
pub fn non_recoverable( request_index: usize, error_code: String, error_message: String, ) -> Self
Create a non-recoverable error
Sourcepub fn is_recoverable(&self) -> bool
pub fn is_recoverable(&self) -> bool
Check if this error is recoverable